==> kiramibot-0.3.0.tar.gz: kiramibot-0.3.0/README.md <==

<div align="center">

# KiramiBot

✨ 简明轻快的聊天机器人应用 ✨

</div>

<p align="center">
  <a href="https://raw.githubusercontent.com/A-kirami/KiramiBot/master/LICENSE">
    <img src="https://img.shields.io/github/license/A-kirami/KiramiBot" alt="license">
  </a>
  <a href="https://pypi.python.org/pypi/kiramibot">
    <img src="https://img.shields.io/pypi/v/kiramibot?logo=python&logoColor=edb641" alt="pypi">
  </a>
  <img src="https://img.shields.io/badge/python-3.10+-blue?logo=python&logoColor=edb641" alt="python">
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?logo=python&logoColor=edb641" alt="black">
  </a>
  <a href="https://github.com/Microsoft/pyright">
    <img src="https://img.shields.io/badge/types-pyright-797952.svg?logo=python&logoColor=edb641" alt="pyright">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json" alt="ruff">
  </a>
  <br />
  <a href="https://results.pre-commit.ci/latest/github/A-kirami/KiramiBot/main">
    <img src="https://results.pre-commit.ci/badge/github/A-kirami/KiramiBot/main.svg" alt="pre-commit" />
  </a>
  <a href="https://github.com/A-kirami/KiramiBot/actions/workflows/pyright.yml">
    <img src="https://github.com/A-kirami/KiramiBot/actions/workflows/pyright.yml/badge.svg?branch=main&event=push" alt="pyright">
  </a>
  <a href="https://github.com/A-kirami/KiramiBot/actions/workflows/ruff.yml">
    <img src="https://github.com/A-kirami/KiramiBot/actions/workflows/ruff.yml/badge.svg?branch=main&event=push" alt="ruff">
  </a>
  <br />
  <a href="https://kiramibot.dev" target="__blank">
    <strong>📖 官方文档</strong>
  </a>
  &nbsp;&nbsp;|&nbsp;&nbsp;
  <a href="https://kiramibot.dev/docs/intro" target="__blank">
    <strong>🚀 快速开始</strong>
  </a>
  &nbsp;&nbsp;|&nbsp;&nbsp;
  <a href="https://qm.qq.com/q/7OD95ZDCMM" target="__blank">
    <strong>💬 讨论交流</strong>
  </a>
</p>

## ⭐️ 简介

KiramiBot 基于 **[NoneBot2](https://v2.nonebot.dev/)** 开发，采用 **[OneBotV11](https://11.onebot.dev/)** 协议通信，能够在**协议支持的平台**上与用户进行交互。

## ✨ 特性

- 🎁 **开箱即用**

  - 无门槛一键安装，初次接触更易上手，小白也能即装即用。

- 🎛️ **插件管理**

  - 非侵入式的插件管理系统，支持更细粒度的功能与权限控制，更加便于维护和管理。

- 🤝 **开发友好**

  - KiramiBot 拥有完整的类型注解，同时提供了常用的功能模块，帮助开发者专注于功能本身。

- 🍀 **生态兼容**
  - 兼容 NoneBot2 原生插件，无需修改即可使用，无缝迁移项目。

## 🚀 开始

如果你有兴趣使用 KiramiBot，可以访问[官方文档](https://kiramibot.dev/docs/guide/start/manual-install)了解如何开始使用。

## 📋 路线图

请参阅 [Projects](https://github.com/users/A-kirami/projects/6)

## 🤝 贡献

请参阅[贡献指南](./.github/CONTRIBUTING.md)

## 🎊 活动

![Alt](https://repobeats.axiom.co/api/embed/4cdc60f22b220e807018a8e4a19226bb942f6331.svg "Repobeats analytics image")

## 📄 许可证

Code: AGPL-3.0 - 2023 - Akirami

==> kiramibot-0.3.2.tar.gz: kiramibot-0.3.2/README.md <==
<p align="center">
  <a href="https://kiramibot.dev/">
    <img src="https://raw.githubusercontent.com/A-kirami/KiramiDocs/main/static/img/logo.svg" width="180" height="180" alt="kiramibot logo">
  </a>
</p>

<div align="center">

# KiramiBot

✨ 简明轻快的聊天机器人应用 ✨

</div>

<p align="center">
  <a href="https://raw.githubusercontent.com/A-kirami/KiramiBot/master/LICENSE">
    <img src="https://img.shields.io/github/license/A-kirami/KiramiBot" alt="license">
  </a>
  <a href="https://pypi.python.org/pypi/kiramibot">
    <img src="https://img.shields.io/pypi/v/kiramibot?logo=python&logoColor=edb641" alt="pypi">
  </a>
  <img src="https://img.shields.io/badge/python-3.10+-blue?logo=python&logoColor=edb641" alt="python">
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?logo=python&logoColor=edb641" alt="black">
  </a>
  <a href="https://github.com/Microsoft/pyright">
    <img src="https://img.shields.io/badge/types-pyright-797952.svg?logo=python&logoColor=edb641" alt="pyright">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json" alt="ruff">
  </a>
  <br />
  <a href="https://results.pre-commit.ci/latest/github/A-kirami/KiramiBot/main">
    <img src="https://results.pre-commit.ci/badge/github/A-kirami/KiramiBot/main.svg" alt="pre-commit" />
  </a>
  <a href="https://github.com/A-kirami/KiramiBot/actions/workflows/pyright.yml">
    <img src="https://github.com/A-kirami/KiramiBot/actions/workflows/pyright.yml/badge.svg?branch=main&event=push" alt="pyright">
  </a>
  <a href="https://github.com/A-kirami/KiramiBot/actions/workflows/ruff.yml">
    <img src="https://github.com/A-kirami/KiramiBot/actions/workflows/ruff.yml/badge.svg?branch=main&event=push" alt="ruff">
  </a>
  <br />
  <a href="https://kiramibot.dev" target="__blank">
    <strong>📖 官方文档</strong>
  </a>
  &nbsp;&nbsp;|&nbsp;&nbsp;
  <a href="https://kiramibot.dev/docs/guide/start/installation" target="__blank">
    <strong>🚀 快速开始</strong>
  </a>
  &nbsp;&nbsp;|&nbsp;&nbsp;
  <a href="https://qm.qq.com/q/7OD95ZDCMM" target="__blank">
    <strong>💬 讨论交流</strong>
  </a>
</p>

## ⭐️ 简介

KiramiBot 是一个功能强大的机器人框架，它可以帮助你创建自定义的聊天机器人，用于自动化任务、聊天交互和更多用途。

不论你是开发者还是爱好者，KiramiBot 提供了一个灵活而强大的平台，让你轻松构建自己的机器人应用。

## ✨ 特性

- 🎁 **开箱即用**

  无门槛一键安装，无需复杂配置，小白也能轻松上手。

- 🎛️ **插件管理**

  非侵入式插件管理系统，支持精细的功能和权限控制，更易于维护和管理。

- 🤝 **开发友好**

  具备完整类型注解，包含常用功能模块，助力开发者专注于核心功能。

- 🍀 **生态兼容**

  原生支持 **[NoneBot2](https://v2.nonebot.dev/)** 插件，无需修改代码即可平滑迁移项目。

## 🚀 开始

> [!NOTE]
> 需要 Python 3.10 或更高版本，以及 mongoDB 数据库。

### 安装 Kirami CLI

#### Linux, macOS, Windows (WSL)

```bash
curl -sSL https://install.kiramibot.dev | python3 -
```

#### Windows (Powershell)

```powershell
(Invoke-WebRequest -Uri https://install.kiramibot.dev -UseBasicParsing).Content | py -
```

### 创建项目

```bash
kirami create
```

### 运行项目

```bash
kirami run
```

## 📋 路线图

请参阅 [Projects](https://github.com/users/A-kirami/projects/6)

## 🤝 贡献

请参阅[贡献指南](./.github/CONTRIBUTING.md)

## 🎊 活动

![Alt](https://repobeats.axiom.co/api/embed/4cdc60f22b220e807018a8e4a19226bb942f6331.svg "Repobeats analytics image")

## 📄 许可证

Code: AGPL-3.0 - 2023 - Akirami

Logo: CC-BY-NC-ND, Designs by Akirami
